/* Copyright (c) 2013 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

//
//  GTLMirrorMenuItem.h
//

// ----------------------------------------------------------------------------
// NOTE: This file is generated from Google APIs Discovery Service.
// Service:
//   Google Mirror API (mirror/v1)
// Description:
//   API for interacting with Glass users via the timeline.
// Documentation:
//   https://developers.google.com/glass
// Classes:
//   GTLMirrorMenuItem (0 custom class methods, 4 custom properties)

#if GTL_BUILT_AS_FRAMEWORK
  #import "GTL/GTLObject.h"
#else
  #import "GTLObject.h"
#endif

@class GTLMirrorMenuValue;

// ----------------------------------------------------------------------------
//
//   GTLMirrorMenuItem
//

// A custom menu item that can be presented to the user by a timeline item.

@interface GTLMirrorMenuItem : GTLObject

// Controls the behavior when the user picks the menu option. Allowed values
// are:
// - CUSTOM - Custom action set by the service. When the user selects this
// menuItem, the API triggers a notification to your callbackUrl with the
// userActions.type set to CUSTOM and the userActions.payload set to the ID of
// this menu item. This is the default value.
// - Built-in actions:
// - REPLY - Initiate a reply to the timeline item using the voice recording UI.
// The creator attribute must be set in the timeline item for this menu to be
// available.
// - REPLY_ALL - Same behavior as REPLY. The original timeline item's recipients
// will be added to the reply item.
// - DELETE - Delete the timeline item.
// - SHARE - Share the timeline item with the available contacts.
// - READ_ALOUD - Read the timeline item's speakableText aloud; if this field is
// not set, read the text field; if none of those fields are set, this menu item
// is ignored.
// - VOICE_CALL - Initiate a phone call using the timeline item's
// creator.phone_number attribute as recipient.
// - NAVIGATE - Navigate to the timeline item's location.
// - TOGGLE_PINNED - Toggle the isPinned state of the timeline item.
@property (copy) NSString *action;

// The ID for this menu item. This is generated by the application and is
// treated as an opaque token.
// identifier property maps to 'id' in JSON (to avoid Objective C's 'id').
@property (copy) NSString *identifier;

// If set to true on a CUSTOM menu item, that item will be removed from the menu
// after it is selected.
@property (retain) NSNumber *removeWhenSelected;  // boolValue

// For CUSTOM items, a list of values controlling the appearance of the menu
// item in each of its states. A value for the DEFAULT state must be provided.
// If the PENDING or CONFIRMED states are missing, they will not be shown.
@property (retain) NSArray *values;  // of GTLMirrorMenuValue

@end
